@@ -1,6 +1,6 @@
 
 /**
- *  @file autogen.c
+ * @file autogen.c
  *
  *  This is the main routine for autogen.
  *  @addtogroup autogen
@@ -8,7 +8,7 @@
  */
 
 /*  This file is part of AutoGen.
- *  Copyright (C) 1992-2018 Bruce Korb - all rights reserved
+ *  Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -218,7 +218,7 @@ cleanup_and_abort(int sig)
         exit_cleanup(EXIT_PCLOSE_NOWAIT);
 
         if (HAVE_OPT(NO_ABORT))
-            exit(AUTOGEN_EXIT_USAGE_ERROR);
+            exit(AUTOGEN_EXIT_SYSEXIT_USAGE);
         abort();
     }
 
@@ -270,7 +270,7 @@ cleanup_and_abort(int sig)
     exit_cleanup(EXIT_PCLOSE_NOWAIT);
 
     if (HAVE_OPT(NO_ABORT))
-        exit(AUTOGEN_EXIT_USAGE_ERROR);
+        exit(AUTOGEN_EXIT_SYSEXIT_USAGE);
     abort();
 }
 
@@ -474,7 +474,7 @@ ag_abend_at(char const * msg
         fputc(NL, stderr);
 
     if (HAVE_OPT(NO_ABORT))
-        exit(AUTOGEN_EXIT_USAGE_ERROR);
+        exit(AUTOGEN_EXIT_SYSEXIT_USAGE);
 
 #ifdef DEBUG_ENABLED
     abort();
